@@ -7,13 +7,13 @@
     ("Hinomiko"           . "$(BF|8f;R(B")
     ("Oyanagi"            . "$(B>.Lx(B")
     ("Inokuchi"           . "$(B0f8}(B")
-    ("D.Dhji"              . "$(BF;K!;{(B")
+    ("D-Dhji-A"             . "$(BF;K!;{(B")
     ("Sodani"             . "$(BA>C+(B")
     ("Shijima"            . "$(B;M==K|(B")
     ("Otomaru"            . "$(B254](B")
-    ("Nukajtaku-mae"    . "$(B3[=;BpA0(B")
+    ("Nukaj-Dtaku-mae-A"     . "$(B3[=;BpA0(B")
     ("Magae"              . "$(BGOBX(B")
-    ("Nonoichi-Kdaimae" . "$(BLn!9;T9)BgA0(B")
+    ("Nonoichi-K-Ddaimae-A"  . "$(BLn!9;T9)BgA0(B")
     ("Nonoichi"           . "$(BLn!9;T(B")
     ("Oshino"             . "$(B2!Ln(B")
     ("Shin-Nishikanazawa" . "$(B?7@>6bBt(B")
@@ -24,17 +24,17 @@
     ("Arimagawa"          . "$(BM-4V@n(B")
     ("Nadachi"            . "$(BL>N)(B")
     ("Tsutsuishi"         . "$(BE{@P(B")
-    ("N"                . "$(BG=@8(B")
+    ("N-D-A"                 . "$(BG=@8(B")
     ("Uramoto"            . "$(B1:K\(B")
     ("Kajiyashiki"        . "$(B3a20I_(B")
     ("Itoigawa"           . "$(B;e5{@n(B")
-    ("mi"               . "$(B@D3$(B")
+    ("-Dmi-A"                . "$(B@D3$(B")
     ("Oyashirazu"         . "$(B?FITCN(B")
     ("Ichiburi"           . "$(B;T?6(B")
-    ("Ecch-Miyazaki"    . "$(B1[Cf5\:j(B")
+    ("Ecch-D-Miyazaki-A"     . "$(B1[Cf5\:j(B")
     ("Tomari"             . "$(BGq(B")
-    ("Nyzen"            . "$(BF~A1(B")
-    ("Nishi-Nyzen"      . "$(B@>F~A1(B")
+    ("Ny-Dzen-A"             . "$(BF~A1(B")
+    ("Nishi-Ny-Dzen-A"       . "$(B@>F~A1(B")
     ("Ikuji"              . "$(B@8CO(B")
     ("Kurobe"             . "$(B9uIt(B")
     ("Uozu"               . "$(B5{DE(B")
@@ -45,7 +45,7 @@
     ("Toyama"             . "$(BIY;3(B")
     ("Kureha"             . "$(B8b1)(B")
     ("Kosugi"             . "$(B>.?y(B")
-    ("Ecch-Daimon"      . "$(B1[CfBgLg(B")
+    ("Ecch-D-Daimon-A"       . "$(B1[CfBgLg(B")
     ("Takaoka"            . "$(B9b2,(B")
     ("Nishi-Takaoka"      . "$(B@>9b2,(B")
     ("Fukuoka"            . "$(BJ!2,(B")
@@ -57,16 +57,17 @@
     ("Kanazawa"           . "$(B6bBt(B")
     ("Nishi-Kanazawa"     . "$(B@>6bBt(B")
     ("[JR] Nonoichi"      . "[JR] $(BLn!9;T(B")
-    ("Matt"             . "$(B>>G$(B")
+    ("Matt-D-A"              . "$(B>>G$(B")
     ("Kaga-Kasama"        . "$(B2C2l3^4V(B")
     ("Mikawa"             . "$(BH~@n(B")
     ("Komaiko"            . "$(B>.Iq;R(B")
     ("Terai"              . "$(B;{0f(B")
-    ("Meih"             . "$(BL@Jv(B")
+    ("Meih-D-A"              . "$(BL@Jv(B")
     ("Komatsu"            . "$(B>.>>(B")
+    ("Awazu"              . "$(B0@DE(B")
     ("Tsuruga"            . "$(BFX2l(B")
     ("Shin-Hikida"        . "$(B?7I%ED(B")
-    ("mi-Shiotsu"       . "$(B6a9>1vDE(B")
+    ("-Dmi-Shiotsu-A"        . "$(B6a9>1vDE(B")
     ("Yogo"               . "$(BM>8b(B")
     ("Kinomoto"           . "$(BLZ%NK\(B")
     ("Takatsuki"          . "$(B9b7n(B")
@@ -75,20 +76,20 @@
     ("Nagahama"           . "$(BD9IM(B")
     ("Tamura"             . "$(BEDB<(B")
     ("Sakata"             . "$(B:dED(B")
-    ("Tky"            . "$(BEl5~(B")
+    ("T-Dky-A"              . "$(BEl5~(B")
     ("Shinbashi"          . "$(B?766(B")
     ("Shinagawa"          . "$(BIJ@n(B")
     ("Kawasaki"           . "$(B@n:j(B")
     ("Yokohama"           . "$(B2#IM(B")
     ("Totsuka"            . "$(B8MDM(B")
-    ("funa"             . "$(BBgA%(B")
+    ("-Dfuna-A"              . "$(BBgA%(B")
     ("Fujisawa"           . "$(BF#Bt(B")
-    ("Tsujid"           . "$(BDTF2(B")
+    ("Tsujid-D-A"            . "$(@DT$(BF2(B")
     ("Chigasaki"          . "$(B3}%v:j(B")
     ("Hiratsuka"          . "$(BJ?DM(B")
-    ("iso"              . "$(BBg0k(B")
+    ("-Diso-A"               . "$(BBg0k(B")
     ("Ninomiya"           . "$(BFs5\(B")
-    ("Kzu"              . "$(B9qI\DE(B")
+    ("K-Dzu-A"               . "$(B9qI\DE(B")
     ("Kamonomiya"         . "$(B3{5\(B")
     ("Odawara"            . "$(B>.ED86(B")
     ("Hayakawa"           . "$(BAa@n(B")
@@ -117,15 +118,15 @@
     ("Yaizu"              . "$(B>FDE(B")
     ("Nishi-Yaizu"        . "$(B@>>FDE(B")
     ("Fijieda"            . "$(BF#;^(B")
-    ("Rokug"            . "$(BO;9g(B")
+    ("Rokug-D-A"             . "$(BO;9g(B")
     ("Shimada"            . "$(BEgED(B")
     ("Kanaya"             . "$(B6bC+(B")
     ("Kikugawa"           . "$(B5F@n(B")
     ("Kakegawa"           . "$(B3]@n(B")
     ("Fukuroi"            . "$(BB^0f(B")
     ("Iwata"              . "$(BHXED(B")
-    ("Toyodach"         . "$(BK-EDD.(B")
-    ("Tenrygawa"        . "$(BE7N5@n(B")
+    ("Toyodach-D-A"          . "$(BK-EDD.(B")
+    ("Tenry-Dgawa-A"         . "$(BE7N5@n(B")
     ("Hamamatsu"          . "$(BIM>>(B")
     ("Takatsuka"          . "$(B9bDM(B")
     ("Maisaka"            . "$(BIq:e(B")
@@ -136,27 +137,27 @@
     ("Futagawa"           . "$(BFs2O(B")
     ("Toyohashi"          . "$(BK-66(B")
     ("Kanayama"           . "$(B6b;3(B")
-    ("Otbashi"          . "$(BHxF,66(B")
+    ("Ot-Dbashi-A"           . "$(BHxF,66(B")
     ("Nagoya"             . "$(BL>8E20(B")
     ("Gifu"               . "$(B4tIl(B")
     ("Samegai"            . "$(B@C%v0f(B")
     ("Maibara"            . "$(BJF86(B")
     ("Kusatsu"            . "$(BApDE(B")
     ("Yamashina"          . "$(B;32J(B")
-    ("Kyto"             . "$(B5~ET(B")
-    ("saka"             . "$(BBg:e(B")
-    ("Kbe"              . "$(B?@8M(B")
+    ("Ky-Dto-A"              . "$(B5~ET(B")
+    ("-Dsaka-A"              . "$(BBg:e(B")
+    ("K-Dbe-A"               . "$(B?@8M(B")
     ("Himi"               . "$(BI98+(B")
     ("Shimao"             . "$(BEgHx(B")
     ("Amaharashi"         . "$(B1+@2(B")
-    ("Ecch-Kokubu"      . "$(B1[Cf9qJ,(B")
+    ("Ecch-D-Kokubu-A"       . "$(B1[Cf9qJ,(B")
     ("Fushiki"            . "$(BIzLZ(B")
-    ("Nmachi"           . "$(BG=D.(B")
-    ("Ecch-Nakagawa"    . "$(B1[CfCf@n(B")
+    ("N-Dmachi-A"            . "$(BG=D.(B")
+    ("Ecch-D-Nakagawa-A"     . "$(B1[CfCf@n(B")
     ("Takaoka"            . "$(B9b2,(B")
     ("Saigata"            . "$(B:T3c(B")
     ("Kubiki"             . "$(B$/$S$-(B")
-    ("ike-Ikoinomori"   . "$(BBgCS$$$3$$$N?9(B")
-    ("Nishi-tsu"        . "$(B@>BgDE(B")))
+    ("-Dike-Ikoinomori-A"    . "$(BBgCS$$$3$$$N?9(B")
+    ("Nishi--Dtsu-A"         . "$(B@>BgDE(B")))
 
 (provide 'rail-semi)
